@@ -125,7 +125,9 @@ class CollectionView(View):
         if c.request.route[-1:] == ['index']:
             return redirect_to('/'+'/'.join(c.request.route[:-1]), **kwargs)
 
-        actions = user.can('create', c) and ['New'] or []
+        actions = user.can('create', c) and [
+            ('New', zoom.url_for(c.url, 'new'))
+        ] or []
 
         logger = logging.getLogger(__name__)
         if q:
@@ -207,6 +209,8 @@ class CollectionView(View):
         """Return a New Item form"""
         c = self.collection
         c.user.authorize('create', c)
+        if kwargs:
+            c.fields.validate(kwargs)
         form = form_for(c.fields, ButtonField('Create', cancel=c.url))
         return page(form, title='New '+c.item_title)
 
@@ -960,3 +964,8 @@ class Collection(object):
 class SilentCollection(Collection):
     """A collection of Records where we do not audit "View" events"""
     verbose = False
+
+
+def collection_of(fields, **kwargs):
+    """Returns a collection"""
+    return Collection(fields, **kwargs)
